@@ -3,6 +3,8 @@ use strict;
 use warnings;
 use Carp;
 use HTML::Template;
+use LEOCHARRE::DEBUG;
+
 require Exporter;
 use vars qw(@EXPORT_OK @ISA %EXPORT_TAGS);
 @ISA = qw(Exporter);
@@ -10,7 +12,7 @@ use vars qw(@EXPORT_OK @ISA %EXPORT_TAGS);
 %EXPORT_TAGS = ( 
 	all => \@EXPORT_OK,
 );
-our $VERSION = sprintf "%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 1.2 $ =~ /(\d+)/g;
 
 =pod
 
@@ -26,12 +28,12 @@ This module allows me to do this, without requiring that tmpl files be in place,
 
 Of course you don't have to use CGI::Application to find this module useful.
 
-The files are sought in ENV TMPL_PATH
+The files are sought in $ENV{HTML_TEMPLATE_PATH}, ( $ENV{TMPL_PATH}  will deprecate )
 
 =head1 SYNOPSIS
 
    use HTML::Template::Default 'get_tmpl';
-   $ENV{TMPL_PATH} = '/home/myself/public_html/templates';
+   $ENV{HTML_TEMPLATE_PATH} = '/home/myself/public_html/templates';
 
    my $default = '
    <html>
@@ -57,65 +59,78 @@ The files are sought in ENV TMPL_PATH
 
 =cut
 
-$HTML::Template::Default::DEBUG = 0;
-sub DEBUG : lvalue { $HTML::Template::Default::DEBUG }
 
+sub _get_tmpl {
+   my $filename = shift;
+   $filename or die;
 
-# quick way to allow designer to override a template, if not on disk, use provided
-# this sub expects filename (filename) 
-sub get_tmpl { # tmpl (d)efault (o)r (o)verride
-	my $label = shift; 
-	$label or croak('get_tmpl(): no filename provided');
-	my $default = shift;
-	
-	print STDERR "get_tmpl() called for [$label]\ndefault provided:".($default ? 1 :0)."\n" if DEBUG;
-	
-	my $_tmpl;	
+   if ( defined $ENV{HTML_TEMPLATE_PATH} and $ENV{HTML_TEMPLATE_PATH} ){
+      if (-f "$ENV{HTML_TEMPLATE_PATH}/$filename"){
+         debug("$filename : ondisk : $ENV{HTML_TEMPLATE_PATH}/$filename\n");
+         return "$ENV{HTML_TEMPLATE_PATH}/$filename";
+      }
+      # otherwise just return if it was set
+      debug("$filename : ondisk : not on disk.\n");
+      return;
+   }
 
+   $ENV{TMPL_PATH}||='./';
 
-	if ($label=~/^\//){
-			$_tmpl = new HTML::Template(  filename => "$label", die_on_bad_params => 0 );
-			print STDERR "found abs path tmpl : $label used.\n" if DEBUG;			
-			return $_tmpl;
-	}
-
-	elsif ($ENV{TMPL_PATH} and -f "$ENV{TMPL_PATH}/$label"){
-			$_tmpl = new HTML::Template(  filename => "$ENV{TMPL_PATH}/$label", die_on_bad_params => 0 );
-			print STDERR "found ENV TMPL_PATH tmpl : $ENV{TMPL_PATH}/$label used.\n" if DEBUG;			
-			return $_tmpl;
-	} 	
-
-	elsif ($default){  # a default tmpl present
-			$_tmpl = new HTML::Template( die_on_bad_params => 0, scalarref => $default );	
-			print STDERR "default provided for [$label] used.\n"if DEBUG;
-			return $_tmpl;
-	}
-
-	croak("get_tmpl(): no template file found and no default provided for [$label]");
-	
+   if (-f $ENV{TMPL_PATH}."/$filename"){
+      debug("$filename : ondisk : $ENV{TMPL_PATH}/$filename\n");
+      return $ENV{TMPL_PATH}."/$filename";
+   }
+   debug("$filename : not on disk.\n");
+   return;
 }
 
+
+
+
+
+sub get_tmpl {
+   my ($filename, $default_code ) = @_;
+   defined $filename or confess('no filename provided');
+   
+   my $tmpl;
+   my $abs_path; 
+   
+   if ( $abs_path = _get_tmpl($filename)){
+
+      $tmpl = new HTML::Template(  filename => $abs_path, die_on_bad_params => 0 ) or die;
+      return $tmpl;
+   }
+
+   defined $default_code and $default_code or confess("$filename was not found and no default code was provided.");
+   ref $default_code or confess("default code for $filename is not a scalarref");
+      
+   $tmpl = new HTML::Template( die_on_bad_params => 0, scalarref => $default_code ) or die;
+
+   return $tmpl;        
+}
+
+
 =head2 get_tmpl()
 
 Takes two arguments. Returns HTML::Template object.
 
 First is a path or filename to an HTML::Template file.
 If the path to template is not absolute (if it's just a filename, ie:'this.html')
-it will seek it inside ENV TMPL_PATH.
+it will seek it inside $ENV{TEMPLATE_PATH}.
 
 Second argument, optional, is a scalar with default code for the template.
 This is what allows a user to override the default look by simply creating a file inside 
-the ENV TMPL_PATH.
+the $ENV{HTML_TEMPLATE_PATH}.
 
 
 Returns HTML::Template object. The HTML::Template object returned will have a die_on_bad_params set to 0.
 
 (If you are creating a handler, you can use get_tmpl() to provide a default template to feed stuff into.
-This also allows user to place a template of their own in the TMPL_PATH directory.)
+This also allows user to place a template of their own in the $ENV{HTML_TEMPLATE_PATH} directory.)
 
 =head3 Example 1
 
-In the following example, if main.html does not exist in ENV TMPL_PATH, the '$default' 
+In the following example, if main.html does not exist in $ENV{HTML_TEMPLATE_PATH}, the '$default' 
 code provided is used as the template.
 
 	my $default = "<html>
@@ -129,15 +144,15 @@ code provided is used as the template.
 
 	my $tmpl = get_tmpl('main.html',$default);
 
-To override that template, one would create the file main.html in ENV TMPL_PATH. The perl
+To override that template, one would create the file main.html in $ENV{HTML_TEMPLATE_PATH}. The perl
 code need not change. This merely lets you provide a default, optionally.
 
-Again, if main.html is not in TMPL_PATH, it will use default string provided- 
+Again, if main.html is not in $ENV{HTML_TEMPLATE_PATH}, it will use default string provided- 
 if no default string provided, and filename is not found, croaks.
 
 =head3 Example 2
 
-In the following example, the template file 'awesome.html' must exist in ENV TMPL_PATH.
+In the following example, the template file 'awesome.html' must exist in $ENV{HTML_TEMPLATE_PATH}.
 Or the application croaks. Because no default is provided.
 
 	my $tmpl = get_tmpl('awesome.html');
@@ -152,6 +167,10 @@ To set debug:
 
 Leo Charre leocharre at cpan dot org
 
+=head1 SEE ALSO
+
+L<HTML::Template>
+
 =cut
 
 
